import React$1 from 'react';
import { PrismTheme } from 'prism-react-renderer';
export { PrismTheme } from 'prism-react-renderer';

interface IToken {
    types: string[];
    content: string;
    empty?: boolean;
}
declare type IStyleObj = Record<string, string | number | null>;
interface ILineInputProps {
    key?: React.Key;
    style?: IStyleObj;
    className?: string;
    line: IToken[];
    [otherProp: string]: any;
}
interface ILineOutputProps {
    key?: React.Key;
    style?: IStyleObj;
    className: string;
    [otherProps: string]: any;
}
interface ITokenInputProps {
    key?: React.Key;
    style?: IStyleObj;
    className?: string;
    token: IToken;
    [otherProp: string]: any;
}
interface ITokenOutputProps {
    key?: React.Key;
    style?: IStyleObj;
    className: string;
    children: string;
    [otherProp: string]: any;
}
interface IRenderProps {
    tokens: IToken[][];
    className?: string;
    style: IStyleObj;
    getLineProps(input: ILineInputProps): ILineOutputProps;
    getTokenProps(input: ITokenInputProps): ITokenOutputProps;
}

interface ICodeHighlighterProps {
    /**
     * Source code contents
     */
    value: string;
    /**
     * Code language
     */
    lang?: string | null;
    /**
     * Line number of Lines that should be highlighted.
     */
    highlightLinenos?: number[];
    /**
     * Whether the code block is in a collapsed state.
     */
    collapsed?: boolean;
    /**
     * Maximum number of rows displayed
     */
    maxLines?: number;
    /**
     * Line height.
     */
    lineHeight?: React.CSSProperties['lineHeight'];
    /**
     * Whether should display line numbers.
     */
    showLineNo?: boolean;
    /**
     * If true, use vscDarkTheme as default theme,
     * otherwise use vscLightTheme as default theme.
     * @default true
     */
    darken?: boolean;
    /**
     * Highlight prism theme.
     */
    theme?: PrismTheme;
    /**
     * Ref of the codes area.
     */
    codesRef?: React.RefCallback<HTMLDivElement> | React.RefObject<HTMLDivElement>;
    /**
     * Callback when linenoWidth changed.
     */
    onLinenoWidthChange?(linenoWidth: React.CSSProperties['width']): void;
}
interface IHighlightContentProps extends IRenderProps {
    /**
     * Line number of Lines that should be highlighted.
     * @default []
     */
    highlightLinenos?: number[];
    /**
     * Whether the code block is in a collapsed state.
     * @default false
     */
    collapsed?: boolean;
    /**
     * Maximum number of rows displayed
     * @default -1
     */
    maxLines?: number;
    /**
     * Line height.
     * @default '1.6rem'
     */
    lineHeight?: React.CSSProperties['lineHeight'];
    /**
     * Whether should display line numbers.
     * @default true
     */
    showLineNo?: boolean;
    /**
     * Ref of the codes area.
     */
    codesRef?: React.RefCallback<HTMLDivElement> | React.RefObject<HTMLDivElement>;
    /**
     * Callback when linenoWidth changed.
     */
    onLinenoWidthChange?(linenoWidth: React.CSSProperties['width']): void;
}

declare const CodeHighlighter: React$1.FC<ICodeHighlighterProps>;

/**
 * Content of CodeHighlighter.
 */
declare const CodeHighlighterContent: React$1.FC<IHighlightContentProps>;

/**
 * Generated Prism Theme from VSCode .json Themes
 *
 * @see https://github.com/FormidableLabs/prism-react-renderer/blob/95025358684be04865669bb912e8cf6203c1a391/tools/themeFromVsCode/README.md
 */
declare const vscDarkTheme: PrismTheme;

/**
 * Generated Prism Theme from VSCode .json Themes
 *
 * @see https://github.com/FormidableLabs/prism-react-renderer/blob/95025358684be04865669bb912e8cf6203c1a391/tools/themeFromVsCode/README.md
 */
declare const vscLightTheme: PrismTheme;

export { CodeHighlighter, CodeHighlighterContent, ICodeHighlighterProps, IHighlightContentProps, CodeHighlighter as default, vscDarkTheme, vscLightTheme };
